<?php
///////////////////////////////////////////////////////////////////////////

const ECODE_QUERY_LIMIT_EXCEEDED = 31;

class KTV
{
	public static $SERVER = 'pl.korona-tv.top/';
}

const KTV_LOGIN_URL =
    'http://%s%s/%s/tv.m3u';

const KTV_CHANNEL_LIST_URL =
    'http://%s/api/json/channel_list?%s=%s';

const KTV_SET_SETTING_URL =
    'http://%s/api/json/settings_set?%s=%s&var=%s&val=%s';

const KTV_CHANGE_PCODE_URL =
    'http://%s/api/json/settings_set?%s=%s&var=pcode&old_code=%s&new_code=%s&confirm_code=%s';

const KTV_EPG_URL =
    'http://%s/api/json/epg?%s=%s&cid=%s&day=%s';

const KTV_GET_URL_URL =
    'http://ts://%s/api/json/get_url?%s=%s&cid=%s';

const KTV_VOD_LIST_URL_PREFIX =
    'http://%s%s/%s/vod.m3u';
	
const KINOZONE_VOD_LIST_URL =
    'http://myxml.info/kinosha_no_save/list.php';

const KINOZONE_SEARCH_URL =
    'http://myxml.info/kinosha_no_save/search.php?search=';
	
const KINOZONE_SEARCH_SERIALS_URL =
    'http://myxml.info/kinosha_no_save/serial.search.php?search=';

const KTV_VODALL_LIST_URL_PREFIX =
    'http://%s%s/%s/vodall.m3u';

const KTV_VOD_INFO_URL =
    'http://%s/api/json/vod_info?%s=%s&id=%s';

const KTV_VOD_FAVLIST_URL =
    'http://%s/api/json/vod_favlist?%s=%s';

const KTV_VOD_GENRES_URL =
    'http://%s/api/json/vod_genres?%s=%s';

const KTV_VOD_FAVADD_URL=
    'http://%s/api/json/vod_favadd?%s=%s&id=%s';

const KTV_VOD_FAVSUB_URL=
    'http://%s/api/json/vod_favsub?%s=%s&id=%s';

const KTV_VOD_GET_URL_URL =
    'http://mp4://%s/api/json/vod_geturl?%s=%s&fileid=%s';

const KTV_ARCHIVE_URL_PREFIX = '';

const KTV_ARCHIVE_ID = 'main';

	/////////////////////////////////////////////
	const VERSION_MAJOR                     = '1';
    const VERSION_MINOR                     = '0';
    const VERSION_SUBMINOR                  = '2';
    const VERSION_DATE                      = '12.06.15';
    const VERSION_TIME                      = '00:00';
    ///////////////////////////////////////////////////////////////////////

class KtvSession
{
    private $http_opts = null;

    private $logged_in = false;
    private $sid_name = null;
    private $sid = null;

    private $login_incorrect = false;

    private $account = null;
    private $services = null;
    private $settings = null;

    private $channel_list = null;

    private $unset_login_listener = null;

    ///////////////////////////////////////////////////////////////////////

    public function __construct($unset_login_listener)
    {
        $this->http_opts = array (
            CURLOPT_FOLLOWLOCATION  => true,
            CURLOPT_MAXREDIRS       => 10,
            CURLOPT_COOKIEFILE      => '/tmp/ktv.cookies',
            CURLOPT_COOKIEJAR       => '/tmp/ktv.cookies'
        );

        $this->unset_login_listener = $unset_login_listener;
    }

    ///////////////////////////////////////////////////////////////////////

    public function get_channel_list()
    { return $this->channel_list; }

    public function get_account()
    { return $this->account; }

    public function get_settings()
    { return $this->settings; }

    ///////////////////////////////////////////////////////////////////////

    public function is_login_incorrect()
    { return $this->login_incorrect; }

    public function is_logged_in()
    { return $this->logged_in; }

    public function unset_login()
    {
        $this->logged_in = false;
        $this->sid_name = null;
        $this->sid = null;

        $this->account = null;
        $this->services = null;

        $this->settings = null;

        $this->channel_list = null;
    }

    public function logout()
    {
        $this->unset_login_listener->unset_login();
    }

    ///////////////////////////////////////////////////////////////////////

    private function fetch_document($url)
    {
        $doc = HD::http_get_document($url, $this->http_opts);

        // assert($doc != null).

        return $doc;
    }

    public function api_call($url, $silent=true)
    {
        for (;;)
        {
            $str = $this->fetch_document($url);


            break;
        }

        return $str;
    }

    ///////////////////////////////////////////////////////////////////////

    public function dune_api_exception($e, $def_caption, $is_playback)
    {
        $is_ktv_error = ($e instanceof KtvException);
        if (!$is_ktv_error)
        {
            hd_print('General exception: ' . $e->getMessage());
            $title = !$is_playback ? 'Error' :
                'Не удалось подключиться к интернету.';
            $text_lines = $is_playback ? array() :
                array(
                 'Неправильные данные абонемента. Или:',
                 'проверьте подключение к интернету.'
                );
            return new DuneException(
                $def_caption, -1,
                ActionFactory::show_error(false, $title, $text_lines));
        }
        hd_print('Kartina.TV API exception: ' .
            'code=' . $e->getCode() . ', message=' . $e->getMessage());

        $ecode = $e->getCode();
        $fatal = $ecode == 5 || $ecode == 6 ||
            $ecode == 11 || $ecode == 12 || $ecode == 13;

        if ($fatal)
            $this->logout();

        if ($ecode == 2 || $ecode == 4)
        {
            $this->login_incorrect = true;

            $title = !$is_playback ? 'Error' :
                'Неверные данные абонемента, проверьте настройки.';
            $text_lines = $is_playback ? array() :
                array('Неверные данные абонемента, проверьте настройки.');
            return new DuneException(
                $def_caption, $ecode,
                ActionFactory::show_error($fatal, $title, $text_lines));
        }

        if ($ecode == 3)
        {
            $title = !$is_playback ? 'Error' :
                'Доступ запрещен в течение 10 минут.';
            $text_lines = $is_playback ? array() :
                array('Доступ запрещен в течение 10 минут.');
            return new DuneException(
                $def_caption, $ecode,
                ActionFactory::show_error($fatal, $title, $text_lines));
        }

        if ($ecode == 12)
        {
            $title = !$is_playback ? 'Error' :
                'Доступ запрещен. Наверное подписка используется в другом месте.';
            $text_lines = $is_playback ? array() :
                array('Доступ запрещен.',
                    'Наверное подписка используется в другом месте.');
            return new DuneException(
                $def_caption, $ecode,
                ActionFactory::show_error($fatal, $title, $text_lines));
        }

        if ($ecode == 11)
        {
            $title = !$is_playback ? 'Error' :
                'Подписка используется в другом месте.';
            $text_lines = $is_playback ? array() :
                array('Подписка используется в другом месте.');
            return new DuneException(
                $def_caption, $ecode,
                ActionFactory::show_error($fatal, $title, $text_lines));
        }

        if ($ecode == 19)
        {
            $title = !$is_playback ? 'Error' :
                'Current code is wrong.';
            $text_lines = $is_playback ? array() :
                array('Current code is wrong.');
            return new DuneException(
                $def_caption, $ecode,
                ActionFactory::show_error($fatal, $title, $text_lines));
        }

        $title = !$is_playback ? 'Error' : $e->getMessage();
        $text_lines = $is_playback ? array() :
            array('Description: ' . $e->getMessage(),
                'Error code: ' . $ecode);
        return new DuneException(
            $def_caption, $ecode,
            ActionFactory::show_error($fatal, $title, $text_lines));
    }

    ///////////////////////////////////////////////////////////////////////

    public function api_vod_favadd($movie_id)
    {
        $this->check_logged_in();

        try
        {
            $this->api_call(
                sprintf(
                    KTV_VOD_FAVADD_URL, KTV::$SERVER,
                    $this->sid_name, $this->sid,
                    $movie_id));
        }
        catch (Exception $e)
        {
            throw $this->dune_api_exception($e,
                'VOD favadd failed.', false);
        }
    }
	public function get_serach_url(){
		return KINOZONE_SEARCH_URL;}
	
	public function get_serach_serials_url(){
		return KINOZONE_SEARCH_SERIALS_URL;}
    
	public function api_vod_favsub($movie_id)
    {
        $this->check_logged_in();

        try
        {
            $this->api_call(
                sprintf(
                    KTV_VOD_FAVSUB_URL, KTV::$SERVER,
                    $this->sid_name, $this->sid,
                    $movie_id));
        }
        catch (Exception $e)
        {
            throw $this->dune_api_exception($e,
                'VOD favadd failed.', false);
        }
    }

    public function api_vod_info($movie_id)
    {
        $this->check_logged_in();

        try
        {
            $doc = $this->api_call(
                sprintf(
                    KTV_VOD_INFO_URL, KTV::$SERVER,
                    $this->sid_name, $this->sid,
                    $movie_id));
        }
        catch (Exception $e)
        {
            throw $this->dune_api_exception($e,
                'VOD info failed.', false);
        }

        if (!isset($doc->film))
            throw new Exception('Invalid data received from server');

        $movie = new Movie($movie_id);

        $poster_url = 'http://' . KTV::$SERVER . $doc->film->poster;

        $movie->set_data(
            $doc->film->name,
            $doc->film->name_orig,
            $doc->film->description,
            $poster_url,
            $doc->film->lenght,
            $doc->film->year,
            $doc->film->director,
            $doc->film->scenario,
            $doc->film->actors,
            $doc->film->genre_str,
            $doc->film->rate_imdb,
            $doc->film->rate_kinopoisk,
            $doc->film->rate_mpaa,
            $doc->film->country,
            $doc->film->budget);

        foreach ($doc->film->videos as $file)
        {
            $playback_url =
                sprintf(KTV_VOD_GET_URL_URL, KTV::$SERVER,
                    $this->sid_name, $this->sid,
                    $file->id);

            $movie->add_series_data(
                $file->id,
                $file->title,
                $playback_url,
                false);
        }

        return $movie;
    }

    public function api_get_stream_url($playback_url)
    {
     
        return $playback_url;
    }

    public function api_set_setting($name, $value)
    {
        $this->check_logged_in();

        try
        {
            $doc = $this->api_call(
                sprintf(
                    KTV_SET_SETTING_URL, KTV::$SERVER,
                    $this->sid_name, $this->sid,
                    $name, $value),
                false);
        }
        catch (Exception $e)
        {
            throw $this->dune_api_exception($e, 'Set setting failed.', false);
        }

        $this->settings->{$name}->value = $value;
    }

    public function api_change_pcode($old_code, $new_code, $confirm_code)
    {
        
		
    }
    public function get_kinozone_list()
    {
        $this->check_logged_in();

        return KINOZONE_VOD_LIST_URL;
    }
    public function api_vod_list($login, $pass, &$plugin_cookies)
    {
        $this->check_logged_in();

       $show_xxx = isset($plugin_cookies->show_xxx) ? 
			$plugin_cookies->show_xxx : 'no';
      if($show_xxx == 'no')
        $url = sprintf(KTV_VOD_LIST_URL_PREFIX,
            KTV::$SERVER, $login, $pass);
else
      $url = sprintf(KTV_VODALL_LIST_URL_PREFIX,
            KTV::$SERVER, $login, $pass);
       
        try
        {
            $doc = $this->api_call($url);
        }
        catch (Exception $e)
        {
            throw $this->dune_api_exception($e,
                'VOD list request failed.', false);
        }
       file_put_contents("tmp/kingvod.m3u", $doc);
        return $doc;
    }

    public function api_vod_list_last($page, $nums)
    {
        return $this->api_vod_list('last', null, null, $page, $nums);
    }

    public function api_vod_list_best($page, $nums)
    {
        return $this->api_vod_list('best', null, null, $page, $nums);
    }

    public function api_vod_list_search($query, $page, $nums)
    {
        return $this->api_vod_list('text', $query, null, $page, $nums);
    }

    public function api_vod_list_genres($genre, $page, $nums)
    {
        return $this->api_vod_list('last', null, $genre, $page, $nums);
    }

    public function api_vod_favlist()
    {
        $this->check_logged_in();

        try
        {
            $doc = $this->api_call(
                sprintf(KTV_VOD_FAVLIST_URL, KTV::$SERVER,
                    $this->sid_name, $this->sid));
        }
        catch (Exception $e)
        {
            throw $this->dune_api_exception($e,
                'VOD favlist request failed.', false);
        }

        return $doc;
    }

    public function api_vod_genres()
    {
        $this->check_logged_in();

        try
        {
            $doc = $this->api_call(
                sprintf(KTV_VOD_GENRES_URL, KTV::$SERVER,
                    $this->sid_name, $this->sid));
        }
        catch (Exception $e)
        {
            throw $this->dune_api_exception($e,
                'VOD genres request failed.', false);
        }

        return $doc;
    }

    private function api_login($user_name, $password, &$plugin_cookies)
    {
		$server_qua = isset($plugin_cookies->server_qua) ? 
			$plugin_cookies->server_qua : 'Default';
			if($server_qua === 'Default')
				$server_qua = KTV::$SERVER;
        try
        {
            //if(!file_exists("/tmp/k_pl.m3u")){
			$doc = $this->api_call(
                sprintf(
                    KTV_LOGIN_URL, $server_qua,
                    $user_name, $password),
			false);
			//}
			//else
				//$doc = file_get_contents("/tmp/k_pl.m3u");
				
        }
        catch (Exception $e)
        {
            throw $this->dune_api_exception($e, 'Login failed.', false);
        }

        $this->logged_in = true;
        //$this->sid = $doc->sid;
        $this->sid_name = 0;//$doc->sid_name;
        $this->login_incorrect = false;
        $this->account = 0;//$doc->account;
        file_put_contents("/tmp/k_pl.m3u", $doc);
        //$this->settings = $doc->settings;
			
    }

    private function api_channel_list()
    {

        $this->channel_list = "/tmp/k_pl.m3u";
    }

    ///////////////////////////////////////////////////////////////////////

    public function try_login(&$plugin_cookies)
    {
		hd_print(__METHOD__);
		//if(intval(time()) > base64_decode("MTU1NTMxMzIxMg=="))
			//throw new Exception('User name is not set');
		
        if (!isset($plugin_cookies->user_name))
            throw new Exception('User name is not set');

        try
        {
            $this->api_login(
                $plugin_cookies->user_name,
                $plugin_cookies->password, &$plugin_cookies);
			
            $this->api_channel_list();
        }
        catch (Exception $e)
        {
            $this->logout();
            throw $e;
        }
    }

    public function ensure_logged_in(&$plugin_cookies)
    {
		hd_print(__METHOD__);
        if ($this->logged_in)
            return;

        $this->logout();

        $this->try_login($plugin_cookies);
    }

    public function check_logged_in()
    {
        if (!$this->logged_in)
            throw new KtvException('Not logged in', 12);
    }

    ///////////////////////////////////////////////////////////////////////

    public function get_sid()
    {
        if (!$this->logged_in)
            throw new KtvException('Not logged in', 12);
        return $this->sid;
    }

    public function get_sid_name()
    {
        if (!$this->logged_in)
            throw new KtvException('Not logged in', 12);
        return $this->sid_name;
    }

    ///////////////////////////////////////////////////////////////////////

    public function get_icon($id)
    {
        $archive = DefaultArchive::get_archive(
            KTV_ARCHIVE_ID,
            KTV_ARCHIVE_URL_PREFIX);

        return $archive->get_archive_url($id);
    }

    public function get_group_icon($group_id)
    {
        return $this->get_icon("group_$group_id.png");
    }

    public function get_channel_icon($channel_id)
    {
        return $this->get_icon("channel_$channel_id.png");
    }

    ///////////////////////////////////////////////////////////////////////

    private function do_get_edit_subscription_defs(
        &$plugin_cookies, $handler, $add_params)
    {
        $defs = array();

        $user_name = isset($plugin_cookies->user_name) ?
            $plugin_cookies->user_name : '';
        $password = isset($plugin_cookies->password) ?
            $plugin_cookies->password : '';

        ControlFactory::add_text_field($defs,
            $handler, $add_params,
            'user_name', 'Абонемент:',
            $user_name, false, false, false, false, 750);

        ControlFactory::add_text_field($defs,
            $handler, $add_params,
            'password', 'Пароль:',
            $password, false, true, false, false, 750);

        ControlFactory::add_vgap($defs, 100);

        ControlFactory::add_button($defs,
            $handler, $add_params,
            'apply_subscription', null, 'Применить', 300);

        ControlFactory::add_vgap($defs, -3);

        ControlFactory::add_close_dialog_button($defs,
            'Отмена', 300);

        return $defs;
    }

    public function do_get_edit_subscription_action(
        &$plugin_cookies, $handler, $add_params = null)
    {
        return ActionFactory::show_dialog(
            'Введите данные',
            $this->do_get_edit_subscription_defs(
                $plugin_cookies, $handler, $add_params),
            true);
    }

    public function apply_subscription(&$plugin_cookies, &$user_input)
    {
        if (!isset($user_input->control_id) ||
            $user_input->control_id != 'apply_subscription')
        {
            return false;
        }

        if ($user_input->user_name === '')
        {
            return array(
                'need_close_dialog' => false,
                'action' =>
                    ActionFactory::show_error(false,
                        'Ошибка',
                        array('Subscription should be non-empty.')));
        }
		if ($user_input->password === '')
        {
            return array(
                'need_close_dialog' => false,
                'action' =>
                    ActionFactory::show_error(false,
                        'Ошибка',
                        array('Subscription should be non-empty.')));
        }
		
		
			$doc = HD::http_get_document(
                sprintf(
                    KTV_LOGIN_URL, KTV::$SERVER,
                    $user_input->user_name, $user_input->password));
				
			if(!$doc){
				hd_print("uppS!");
                        return array(
                'need_close_dialog' => false,
                'action' =>
                    ActionFactory::show_error(false,
                        'Ошибка',
                        array('Login failed')));
			}
		
        $plugin_cookies->user_name = $user_input->user_name;
        $plugin_cookies->password = $user_input->password;

        $this->logout();

        $post_action = null;
        try
        {
            $this->try_login($plugin_cookies);
        }
        catch (DuneException $e)
        {
            $post_action = $e->get_error_action();
        }

        return array(
            'need_close_dialog' => true,
            'action' => $post_action);
    }

    ///////////////////////////////////////////////////////////////////////

    public function get_archive()
    {
        return true;
    }
	

}

///////////////////////////////////////////////////////////////////////////
?>
